#
# Fedora spec file for php-behat-mink-browserkit-driver
#
# Copyright (c) 2015-2017 Shawn Iwinski <shawn@iwin.ski>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     minkphp
%global github_name      MinkBrowserKitDriver
%global github_version   1.3.2
%global github_commit    10e67fb4a295efcd62ea0bf16025a85ea19534fb

%global composer_vendor  behat
%global composer_project mink-browserkit-driver

# "php": ">=5.3.6"
%global php_min_ver 5.3.6
# "behat/mink": "^1.7.1@dev"
%global mink_min_ver 1.7.1
%global mink_max_ver 2.0
# "silex/silex": "~1.2"
%global silex_min_ver 1.2
%global silex_max_ver 2.0
# "symfony/browser-kit": "~2.3|~3.0"
# "symfony/dom-crawler": "~2.3|~3.0"
#     NOTE: Min version not 2.3 because autoloader required
%global symfony_min_ver 2.7.1
%global symfony_max_ver 4.0

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%global phpdir   %{_datadir}/php
%global testsdir %{_datadir}/tests

Name:          php-%{composer_vendor}-%{composer_project}
Version:       %{github_version}
Release:       5%{?dist}
Summary:       Symfony BrowserKit driver for Mink framework

Group:         Development/Libraries
License:       MIT
URL:           http://mink.behat.org/en/latest/drivers/browserkit.html
Source0:       https://github.com/%{github_owner}/%{github_name}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

BuildArch:     noarch
# Tests
%if %{with_tests}
BuildRequires: php-composer(phpunit/phpunit)
BuildRequires: php-behat-mink-driver-testsuite
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
BuildRequires: php-composer(behat/mink) <  %{mink_max_ver}
BuildRequires: php-composer(behat/mink) >= %{mink_min_ver}
BuildRequires: php-composer(silex/silex) <  %{silex_max_ver}
BuildRequires: php-composer(silex/silex) >= %{silex_min_ver}
BuildRequires: php-composer(symfony/browser-kit) <  %{symfony_max_ver}
BuildRequires: php-composer(symfony/browser-kit) >= %{symfony_min_ver}
BuildRequires: php-composer(symfony/dom-crawler) <  %{symfony_max_ver}
BuildRequires: php-composer(symfony/dom-crawler) >= %{symfony_min_ver}
## phpcompatinfo (computed from version 1.3.2)
BuildRequires: php-json
BuildRequires: php-pcre
BuildRequires: php-reflection
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
Requires:      php-composer(behat/mink) <  %{mink_max_ver}
Requires:      php-composer(behat/mink) >= %{mink_min_ver}
Requires:      php-composer(symfony/browser-kit) <  %{symfony_max_ver}
Requires:      php-composer(symfony/browser-kit) >= %{symfony_min_ver}
Requires:      php-composer(symfony/dom-crawler) <  %{symfony_max_ver}
Requires:      php-composer(symfony/dom-crawler) >= %{symfony_min_ver}
# phpcompatinfo (computed from version 1.3.2)
Requires:      php-pcre
Requires:      php-reflection
# Autoloader
BuildRequires: php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
BrowserKitDriver provides a bridge for the Symfony BrowserKit [1] component.
BrowserKit is a browser emulator provided by the Symfony project [2].

Autoloader: %{phpdir}/Behat/Mink/Driver/autoload-browserkit.php

[1] http://symfony.com/components/BrowserKit
[2] http://symfony.com/


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Create library autoloader
cat <<'AUTOLOAD' | tee src/autoload-browserkit.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Behat\\Mink\\Driver\\', __DIR__);

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Behat/Mink/autoload.php',
    '%{phpdir}/Symfony/Component/BrowserKit/autoload.php',
    '%{phpdir}/Symfony/Component/DomCrawler/autoload.php',
));
AUTOLOAD


%install
mkdir -p  %{buildroot}%{phpdir}/Behat/Mink/Driver
cp -pr src/* %{buildroot}%{phpdir}/Behat/Mink/Driver/


%check
%if %{with_tests}
: Setup driver testsuite
mkdir -p vendor/behat/mink/
ln -s %{testsdir}/php-behat-mink-driver-testsuite vendor/behat/mink/driver-testsuite

: Create tests bootstrap
cat <<'BOOTSTRAP' | tee bootstrap.php
<?php
require_once '%{buildroot}%{phpdir}/Behat/Mink/Driver/autoload-browserkit.php';

\Fedora\Autoloader\Autoload::addPsr4('Behat\\Mink\\Tests\\Driver\\', __DIR__.'/tests');

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Silex/autoload.php',
    '%{testsdir}/php-behat-mink-driver-testsuite/autoload.php',
));
BOOTSTRAP

: Upstream tests
RETURN_CODE=0
PHPUNIT=$(which phpunit)
for PHP_EXEC in "" %{?rhel:php54 php55} php56 php70 php71 php72; do
    if [ -z "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC $PHPUNIT --verbose --bootstrap bootstrap.php || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{phpdir}/Behat/Mink/Driver/autoload-browserkit.php
%{phpdir}/Behat/Mink/Driver/BrowserKitDriver.php


%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri May 12 2017 Shawn Iwinski <shawn@iwin.ski> - 1.3.2-3
- Switch autoloader to php-composer(fedora/autoloader)
- Add max versions to build dependencies
- Test with SCLs if available

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Aug 09 2016 Shawn Iwinski <shawn@iwin.ski> - 1.3.2-1
- Updated to 1.3.2 (RHBZ #1300118)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 25 2015 Shawn Iwinski <shawn@iwin.ski> - 1.3.0-1
- Initial package
